@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * This file includes excerpts from the Document Object Model (DOM)
  * Level 1 Specification (Recommendation)
@@ -25,12 +25,13 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: html_element.h,v 1.19.2.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef HTML_ELEMENT_H
 #define HTML_ELEMENT_H
 
 #include <dom/dom_element.h>
+#include <kdelibs_export.h>
+
 class KHTMLView;
 
 namespace DOM {
@@ -43,29 +44,29 @@ class HTMLCollection;
 /**
  * All HTML element interfaces derive from this class. Elements that
  * only expose the HTML core attributes are represented by the base
- * <code> HTMLElement </code> interface. These elements are as
+ * \c HTMLElement interface. These elements are as
  * follows:
  *
- *  <ulist> <item> HEAD
+ *  \li \c HEAD
  *
- *  </item> <item> special: SUB, SUP, SPAN, BDO
+ *  \li special: <tt> SUB, SUP, SPAN, BDO </tt>
  *
- *  </item> <item> font: TT, I, B, U, S, STRIKE, BIG, SMALL
+ *  \li font: <tt> TT, I, B, U, S, STRIKE, BIG, SMALL </tt>
  *
- *  </item> <item> phrase: EM, STRONG, DFN, CODE, SAMP, KBD, VAR,
- * CITE, ACRONYM, ABBR
+ *  \li phrase: <tt> EM, STRONG, DFN, CODE, SAMP, KBD, VAR,
+ * CITE, ACRONYM, ABBR</tt>
  *
- *  </item> <item> list: DD, DT
+ *  \li list: <tt> DD, DT </tt>
  *
- *  </item> <item> NOFRAMES, NOSCRIPT
+ *  \li <tt> NOFRAMES, NOSCRIPT </tt>
  *
- *  </item> <item> ADDRESS, CENTER
+ *  \li <tt> ADDRESS, CENTER </tt>
  *
- *  </item> </ulist> Note. The <code> style </code> attribute for this
+ *  Note: The \c style attribute for this
  * interface is reserved for future usage.
  *
  */
-class HTMLElement : public Element
+class KHTML_EXPORT HTMLElement : public Element
 {
     friend class HTMLDocument;
     friend class ::KHTMLView;
@@ -97,7 +98,7 @@ public:
     DOMString id() const;
 
     /**
-     * see @ref id
+     * see id
      */
     void setId( const DOMString & );
 
@@ -110,7 +111,7 @@ public:
     DOMString title() const;
 
     /**
-     * see @ref title
+     * see title
      */
     void setTitle( const DOMString & );
 
@@ -123,7 +124,7 @@ public:
     DOMString lang() const;
 
     /**
-     * see @ref lang
+     * see lang
      */
     void setLang( const DOMString & );
 
@@ -137,7 +138,7 @@ public:
     DOMString dir() const;
 
     /**
-     * see @ref dir
+     * see dir
      */
     void setDir( const DOMString & );
 
@@ -152,7 +153,7 @@ public:
     DOMString className() const;
 
     /**
-     * see @ref className
+     * see className
      */
     void setClassName( const DOMString & );
 
