@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -47,7 +47,7 @@ class KAboutContainerPrivate;
 /**
  *  KAboutContainer can be used to make a application specific AboutDialog.
  */
-class KAboutContainer : public QFrame
+class KDEUI_EXPORT KAboutContainer : public QFrame
 {
   Q_OBJECT
 
@@ -80,7 +80,7 @@ class KAboutContainer : public QFrame
   private:
     QVBoxLayout *mVbox;
     int mAlignment;
-    KAboutContainerPrivate *d;
+    KAboutContainerPrivate* const d;
 };
 
 class KAboutContributorPrivate;
@@ -89,7 +89,7 @@ class KAboutContributorPrivate;
  * Used internally by KAboutWidget
  * @internal
  */
-class KAboutContributor : public QFrame
+class KDEUI_EXPORT KAboutContributor : public QFrame
 {
   Q_OBJECT
 
@@ -137,7 +137,7 @@ class KAboutContributor : public QFrame
     bool mShowHeader;
     bool mShowBold;
 
-    KAboutContributorPrivate *d;
+    KAboutContributorPrivate* const d;
 
 	virtual void setName(const char *_name) { QFrame::setName(_name); }
 };
@@ -147,7 +147,7 @@ class KAboutContributor : public QFrame
  *
  * It has a minimum size set.
  */
-class KAboutWidget : public QWidget
+class KDEUI_EXPORT KAboutWidget : public QWidget
 {
   Q_OBJECT
 
@@ -245,7 +245,7 @@ protected:
   // #########################################################################
   //
 private:
-  KAboutWidgetPrivate *d;
+  KAboutWidgetPrivate* const d;
 };
 
 class KAboutDialogPrivate;
@@ -280,7 +280,7 @@ class KAboutDialogPrivate;
  * @author Mirko Boehm (mirko@kde.org) and Espen Sand (espensa@online.no)
  * @see KDialogBase
  */
-class KAboutDialog : public KDialogBase
+class KDEUI_EXPORT KAboutDialog : public KDialogBase
 {
   Q_OBJECT
 
@@ -390,6 +390,40 @@ class KAboutDialog : public KDialogBase
    */
   void setImage( const QString &fileName );
 
+  /**
+   * (Constructor II only)
+   * Define the program logo to be shown in the dialog.  Use this to override the
+   * default program logo.  For example, use this function if the 
+   * KAboutDialog is for a panel applet and you want to override the
+   * appletproxy logo with your own pixmap.
+   *
+   * @param fileName Path to file containing logo data in a format that 
+   *        can be loaded by QPixmap.
+   *
+   * @since 3.3
+   */
+  void setIcon( const QString &fileName ) KDE_DEPRECATED; // KDE4: remove
+
+  /**
+   * Overloaded version of setProgramLogo(const QPixmap& pixmap).
+   *
+   * @since 3.4
+   */
+  void setProgramLogo( const QString &fileName );
+
+  /**
+   * (Constructor II only)
+   * Define the program logo to be shown in the dialog.  Use this to override the
+   * default program logo. For example, use this function if the 
+   * KAboutDialog is for a panel applet and you want to override the
+   * appletproxy logo with your own pixmap.
+   *
+   * @param pixmap The logo pixmap.
+   *
+   * @since 3.4
+   */
+  void setProgramLogo( const QPixmap &pixmap );
+
   /**
    * (Constructor II only)
    * The image has a minimum size, but is centered within an area if the
@@ -593,7 +627,7 @@ protected slots:
 protected:
   virtual void virtual_hook( int id, void* data );
 private:
-  KAboutDialogPrivate *d;
+  KAboutDialogPrivate* const d;
 };
 
 #endif // defined KABOUTDIALOG_H
