@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: su.h 363273 2004-11-15 22:43:23Z mueller $
+ * $Id: su.h 570635 2006-08-07 13:48:26Z jriddell $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -47,7 +47,6 @@ public:
      * Checks if a password is needed.
      */
     int checkNeedPassword();
-    void setUseSudo(bool sudo);
 
 private:
     enum SuErrors { error=-1, ok=0, killme=1, notauthorized=2 } ;
@@ -58,6 +57,7 @@ protected:
 private:
     class SuProcessPrivate;
     SuProcessPrivate *d;
+    QString superUserCommand;
 };
 
 #endif
