@@ -1,5 +1,5 @@
 /*
-    $Id: kfontdialog.h,v 1.68 2003/09/09 12:40:58 bhards Exp $
+    $Id: kfontdialog.h 465272 2005-09-29 09:47:40Z mueller $
 
     Requires the Qt widget libraries, available at no cost at
     http://www.troll.no
@@ -20,8 +20,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #ifndef _K_FONT_DIALOG_H_
 #define _K_FONT_DIALOG_H_
@@ -39,20 +39,23 @@ class QStringList;
 class KListBox;
 class KIntNumInput;
 /**
+ * @short A font selection widget.
+ *
  * While KFontChooser as an ordinary widget can be embedded in
  * custom dialogs and therefore is very flexible, in most cases
  * it is preferable to use the convenience functions in
  * KFontDialog.
  *
- * @short A font selection widget.
+ * \image html kfontchooser.png "KDE Font Chooser"
+ *
  * @author Preston Brown <pbrown@kde.org>, Bernd Wuebben <wuebben@kde.org>
- * @version $Id: kfontdialog.h,v 1.68 2003/09/09 12:40:58 bhards Exp $
+ * @version $Id: kfontdialog.h 465272 2005-09-29 09:47:40Z mueller $
  */
-class KFontChooser : public QWidget
+class KDEUI_EXPORT KFontChooser : public QWidget
 {
   Q_OBJECT
   Q_PROPERTY( QFont font READ font WRITE setFont )
-  
+
 public:
   /**
    *  @li @p FamilyList - Identifies the family (leftmost) list.
@@ -203,6 +206,17 @@ public:
     sampleEdit->setText( text );
   }
 
+  /**
+   * Shows or hides the sample text box.
+   *
+   * @param visible Set it to true to show the box, to false to hide it.
+   * @since 3.5
+   */
+  void setSampleBoxVisible( bool visible )
+  {
+    sampleEdit->setShown( visible );
+  }
+
   /**
    * Converts a QFont into the corresponding X Logical Font
    * Description (XLFD).
@@ -280,7 +294,7 @@ private:
   KListBox     *familyListBox;
   KListBox     *styleListBox;
   KListBox     *sizeListBox;
-  QComboBox    *charsetsCombo;
+  QComboBox    *charsetsCombo; // BIC: remove in KDE4
   QCheckBox    *sizeIsRelativeCheckBox;
 
   QFont        selFont;
@@ -299,6 +313,8 @@ private:
 };
 
 /**
+ * @short A font selection dialog.
+ *
  * The KFontDialog provides a dialog for interactive font selection.
  * It is basically a thin wrapper around the KFontChooser widget,
  * which can also be used standalone. In most cases, the simplest
@@ -317,11 +333,10 @@ private:
  *
  * \image html kfontdialog.png "KDE Font Dialog"
  *
- * @short A font selection dialog.
  * @author Preston Brown <pbrown@kde.org>, Bernd Wuebben <wuebben@kde.org>
- * @version $Id: kfontdialog.h,v 1.68 2003/09/09 12:40:58 bhards Exp $
+ * @version $Id: kfontdialog.h 465272 2005-09-29 09:47:40Z mueller $
  */
-class KFontDialog : public KDialogBase  {
+class KDEUI_EXPORT KFontDialog : public KDialogBase  {
     Q_OBJECT
 
 public:
