@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 #ifndef __khtml_part_h__
 #define __khtml_part_h__
@@ -32,6 +32,7 @@
 #include <kparts/part.h>
 #include <kparts/browserextension.h>
 #include <kdemacros.h>
+#include <kfinddialog.h>
 
 #include <qregexp.h>
 
@@ -72,7 +73,7 @@ namespace khtml
   class DocLoader;
   class RenderPart;
   class RenderPartObject;
-  struct ChildFrame;
+  class ChildFrame;
   class MouseEvent;
   class MousePressEvent;
   class MouseDoubleClickEvent;
@@ -92,6 +93,7 @@ namespace KJS {
     class WindowFunc;
     class ExternalFunc;
     class JSEventListener;
+    class JSLazyEventListener;
     class JSNodeFilter;
     class DOMDocument;
     class SourceFile;
@@ -177,10 +179,9 @@ namespace KWallet
  *
  * @short HTML Browser Widget
  * @author Lars Knoll (knoll@kde.org)
- * @version $Id: khtml_part.h,v 1.248.2.2 2004/02/29 15:27:44 mueller Exp $
  *
  */
-class KHTMLPart : public KParts::ReadOnlyPart
+class KHTML_EXPORT KHTMLPart : public KParts::ReadOnlyPart
 {
   Q_OBJECT
   friend class KHTMLView;
@@ -200,6 +201,7 @@ class KHTMLPart : public KParts::ReadOnlyPart
   friend class KJS::WindowFunc;
   friend class KJS::ExternalFunc;
   friend class KJS::JSEventListener;
+  friend class KJS::JSLazyEventListener;
   friend class KJS::DOMDocument;
   friend class KJS::SourceFile;
   friend class KJSProxy;
@@ -213,14 +215,21 @@ class KHTMLPart : public KParts::ReadOnlyPart
   friend class khtml::CSSStyleSelector;
   friend class KHTMLPartIface;
   friend class KHTMLPartFunction;
+  friend class KHTMLPopupGUIClient;
 
   Q_PROPERTY( bool javaScriptEnabled READ jScriptEnabled WRITE setJScriptEnabled )
   Q_PROPERTY( bool javaEnabled READ javaEnabled WRITE setJavaEnabled )
   Q_PROPERTY( bool autoloadImages READ autoloadImages WRITE setAutoloadImages )
   Q_PROPERTY( bool dndEnabled READ dndEnabled WRITE setDNDEnabled )
   Q_PROPERTY( bool pluginsEnabled READ pluginsEnabled WRITE setPluginsEnabled )
-  Q_PROPERTY( bool onlyLocalReferences READ onlyLocalReferences WRITE setOnlyLocalReferences )
+
+  /*
+   *
+   * Don't add setOnlyLocalReferences here. It shouldn't be accessible via DCOP.
+   *
+   **/
   Q_PROPERTY( QCString dcopObjectId READ dcopObjectId )
+  Q_PROPERTY( bool modified READ isModified )
 
 public:
   enum GUIProfile { DefaultGUI, BrowserViewGUI /* ... */ };
@@ -277,6 +286,12 @@ public:
    */
   DOM::Document document() const;
 
+  /**
+   * Returns the content of the source document.
+   * @since 3.4
+   */
+   QString documentSource() const;
+
   /**
    * Returns the node that has the keyboard focus.
    */
@@ -287,6 +302,7 @@ public:
    */
   KParts::BrowserExtension *browserExtension() const;
   KParts::LiveConnectExtension *liveConnectExtension( const khtml::RenderPart *) const;
+  KParts::BrowserHostExtension *browserHostExtension() const;
 
   /**
    * Returns a pointer to the HTML document's view.
@@ -327,7 +343,15 @@ public:
   KJS::Interpreter *jScriptInterpreter();
 
   /**
-   * Enable/disable statusbar messages
+   * Enable/disable statusbar messages.
+   * When this class wants to set the statusbar text, it emits
+   * setStatusBarText(const QString & text)
+   * If you want to catch this for your own statusbar, note that it returns
+   * back a rich text string, starting with "<qt>".  This you need to
+   * either pass this into your own QLabel or to strip out the tags
+   * before passing it to QStatusBar::message(const QString & message)
+   *
+   * @see KParts::Part::setStatusBarText( const QString & text )
    */
   void setStatusMessagesEnabled( bool enable );
 
@@ -415,14 +439,24 @@ public:
   /**
    * Security option.
    *
-   * Specify whether only local references ( stylesheets, images, scripts, subdocuments )
-   * should be loaded. ( default false - everything is loaded, if the more specific
-   * options allow )
+   * Specify whether only file:/ or data:/ urls are allowed to be loaded without
+   * user confirmation by KHTML.
+   * ( for example referenced by stylesheets, images, scripts, subdocuments, embedded elements ).
+   *
+   * This option is mainly intended for enabling the "mail reader mode", where you load untrusted
+   * content with a file:/ url.
+   *
+   * Please note that enabling this option currently automatically disables Javascript,
+   * Java and Plugins support. This might change in the future if the security model
+   * is becoming more sophisticated, so don't rely on this behaviour.
+   *
+   * ( default false - everything is loaded unless forbidden by KApplication::authorizeURLAction).
    */
   void setOnlyLocalReferences( bool enable );
 
   /**
-   * Returns whether references should be loaded ( default false )
+   * Returns whether only file:/ or data:/ references are allowed
+   * to be loaded ( default false ).  See setOnlyLocalReferences.
    **/
   bool onlyLocalReferences() const;
 
@@ -596,6 +630,8 @@ public:
    *
    * This gives a wide range of possibilities to
    * change the layout of the page.
+   *
+   * To have an effect this function has to be called after calling begin().
    */
   void setUserStyleSheet( const KURL &url );
 
@@ -605,6 +641,8 @@ public:
    *
    * This gives a wide range of possibilities to
    * change the layout of the page.
+   *
+   * To have an effect this function has to be called after calling begin().
    */
   void setUserStyleSheet( const QString &styleSheet );
 
@@ -658,6 +696,35 @@ public:
    */
   QCursor urlCursor() const;
 
+  /**
+   * Extra Find options that can be used when calling the extended findText().
+   * @since 3.3
+   */
+  enum FindOptions
+  {
+  	FindLinksOnly   = 1 * KFindDialog::MinimumUserOption,
+  	FindNoPopups    = 2 * KFindDialog::MinimumUserOption
+  	//FindIncremental = 4 * KFindDialog::MinimumUserOption
+  };
+
+  /**
+   * Starts a new search by popping up a dialog asking the user what he wants to
+   * search for.
+   * @since 3.3
+   */
+  void findText();
+
+  /**
+   * Starts a new search, but bypasses the user dialog.
+   * @param str The string to search for.
+   * @param options Find options.
+   * @param parent Parent used for centering popups like "string not found".
+   * @param findDialog Optionally, you can supply your own dialog.
+   * @since 3.3
+   */
+  void findText( const QString &str, long options, QWidget *parent = 0,
+                 KFindDialog *findDialog = 0 );
+
   /**
    * Initiates a text search.
    */
@@ -666,9 +733,26 @@ public:
   /**
    * Finds the next occurrence of the string or expression.
    * If isRegExp is true then str is converted to a QRegExp, and caseSensitive is ignored.
+   * @deprecated, use findText( str, options, parent, findDialog )
    */
   bool findTextNext( const QString &str, bool forward, bool caseSensitive, bool isRegExp );
 
+  /**
+   * Finds the next occurence of a string set by @ref findText()
+   * @return true if a new match was found.
+   * @since 3.3
+   */
+  bool findTextNext();
+
+  /**
+   * Finds the next occurence of a string set by @ref findText()
+   * @param reverse if true, revert seach direction (only if no find dialog is used)
+   * @return true if a new match was found.
+   * @since 3.5
+   */
+  // KDE4 merge with default = false
+  bool findTextNext( bool reverse );
+
   /**
    * Sets the Zoom factor. The value is given in percent, larger values mean a
    * generally larger font and larger page contents. It is not guaranteed that
@@ -691,6 +775,16 @@ public:
    */
   virtual QString selectedText() const;
 
+  /**
+   * Return the text the user has marked.  This is guaranteed to be valid xml,
+   * and to contain the \<html> and \<body> tags.
+   *
+   * FIXME probably should make virtual for 4.0 ?
+   *
+   * @since 3.4
+   */
+  QString selectedTextAsHTML() const;
+
   /**
    * Returns the selected part of the HTML.
    */
@@ -770,10 +864,23 @@ public:
   virtual void restoreState( QDataStream &stream );
 
   /**
-   * Returns the @p Node currently under the mouse
+   * Returns the @p Node currently under the mouse.
+   *
+   * The returned node may be a shared node (e. g. an \<area> node if the
+   * mouse is hovering over an image map).
    */
   DOM::Node nodeUnderMouse() const;
 
+  /**
+   * Returns the @p Node currently under the mouse that is not shared.
+   *
+   * The returned node is always the node that is physically under the mouse
+   * pointer (irrespective of logically overlying elements like, e. g.,
+   * \<area> on image maps).
+   * @since 3.3
+   */
+  DOM::Node nonSharedNodeUnderMouse() const;
+
   /**
    * @internal
    */
@@ -801,6 +908,16 @@ public:
    */
   KHTMLPart *findFrame( const QString &f );
 
+  /**
+   * Recursively finds the part containing the frame with name @p f
+   * and checks if it is accessible by @p callingPart
+   * Returns 0L if no suitable frame can't be found.
+   * Returns parent part if a suitable frame was found and
+   * frame info in @p *childFrame
+   * @since 3.3
+   */
+  KHTMLPart *findFrameParent( KParts::ReadOnlyPart *callingPart, const QString &f, khtml::ChildFrame **childFrame=0 );
+
   /**
    * Return the current frame (the one that has focus)
    * Not necessarily a direct child of ours, framesets can be nested.
@@ -816,7 +933,15 @@ public:
    */
   bool frameExists( const QString &frameName );
 
+  /**
+   * Returns child frame framePart its script interpreter
+   */
+  KJSProxy *framejScript(KParts::ReadOnlyPart *framePart);
 
+  /**
+   * Finds a frame by name. Returns 0L if frame can't be found.
+   */
+  KParts::ReadOnlyPart *findFramePart( const QString &f );
   /**
    * Called by KJS.
    * Sets the StatusBarText assigned
@@ -897,11 +1022,37 @@ public:
    * Returns the toplevel (origin) URL of this document, even if this
    * part is a frame or an iframe.
    *
-   * @return the actual orginal url.
+   * @return the actual original url.
    * @since 3.2
    */
   KURL toplevelURL();
 
+  /**
+   * Checks whether the page contains unsubmitted form changes.
+   *
+   * @return true if form changes exist
+   * @since 3.3
+   */
+  bool isModified() const;
+
+  /**
+   * Shows or hides the suppressed popup indicator
+   * @deprecated
+   * @since 3.4
+   */
+  void setSuppressedPopupIndicator( bool enable );
+
+  /**
+   * Shows or hides the suppressed popup indicator
+   * @since 3.5
+   */
+  void setSuppressedPopupIndicator( bool enable, KHTMLPart *originPart );
+
+  /**
+   * @internal
+   * @since 3.5
+   */
+  bool inProgress() const;
 
 signals:
   /**
@@ -984,11 +1135,11 @@ protected:
    */
   virtual void khtmlMouseDoubleClickEvent( khtml::MouseDoubleClickEvent * );
   /**
-   * Eventhandler for the khtml::MouseDoubleMoveEvent.
+   * Eventhandler for the khtml::MouseMouseMoveEvent.
    */
   virtual void khtmlMouseMoveEvent( khtml::MouseMoveEvent *event );
   /**
-   * Eventhandler for the khtml::MouseMoveEvent.
+   * Eventhandler for the khtml::MouseMouseReleaseEvent.
    */
   virtual void khtmlMouseReleaseEvent( khtml::MouseReleaseEvent *event );
   /**
@@ -1220,9 +1371,14 @@ private slots:
   virtual void slotFindDone(); // ### remove me
   virtual void slotFindDialogDestroyed();
   void slotFindNext();
+  void slotFindPrev();
+  void slotFindAheadText();
+  void slotFindAheadLink();
 
   void slotIncZoom();
   void slotDecZoom();
+  void slotIncZoomFast();
+  void slotDecZoomFast();
 
   void slotLoadImages();
   void slotWalletClosed();
@@ -1270,7 +1426,10 @@ private slots:
    * @internal
    */
   void slotChildDocCreated();
-
+  /**
+   * @internal
+   */
+  void slotRequestFocus( KParts::ReadOnlyPart * );
   void slotLoaderRequestStarted( khtml::DocLoader*, khtml::CachedObject* obj);
   void slotLoaderRequestDone( khtml::DocLoader*, khtml::CachedObject *obj );
   void checkCompleted();
@@ -1334,6 +1493,26 @@ private slots:
    */
   void slotToggleCaretMode();
 
+  /**
+   * @internal
+   */
+  void suppressedPopupMenu();
+
+  /**
+   * @internal
+   */
+  void togglePopupPassivePopup();
+
+  /**
+   * @internal
+   */
+  void showSuppressedPopups();
+
+  /**
+   * @internal
+   */
+  void launchJSConfigDialog();
+
   /**
    * @internal
    */
@@ -1354,7 +1533,14 @@ private slots:
    */
   void jsErrorDialogContextMenu();
 
+  /**
+   * @internal
+   * used to restore or reset the view's scroll position (including positioning on anchors)
+   * once a sufficient portion of the document as been laid out.
+   */
+  void restoreScrollPosition();
 
+  void walletOpened(KWallet::Wallet*);
 
 private:
 
@@ -1364,16 +1550,28 @@ private:
   void setStatusBarText( const QString& text, StatusBarPriority p);
 
   bool restoreURL( const KURL &url );
+  void resetFromScript();
   void emitSelectionChanged();
+  // Returns whether callingHtmlPart may access this part
+  bool checkFrameAccess(KHTMLPart *callingHtmlPart);
   bool openURLInFrame( const KURL &url, const KParts::URLArgs &urlArgs );
+  bool urlSelectedIntern( const QString &url, int button, int state,
+                          const QString &_target, KParts::URLArgs args = KParts::URLArgs());
   void startAutoScroll();
   void stopAutoScroll();
   void overURL( const QString &url, const QString &target, bool shiftPressed = false );
+  void resetHoverText(); // Undo overURL and reset HoverText
 
   bool processObjectRequest( khtml::ChildFrame *child, const KURL &url, const QString &mimetype );
 
   KWallet::Wallet* wallet();
 
+  void openWallet(DOM::HTMLFormElementImpl*);
+  void saveToWallet(const QString& key, const QMap<QString,QString>& data);
+  void dequeueWallet(DOM::HTMLFormElementImpl*);
+  
+  void enableFindAheadActions(bool);
+
   /**
    * @internal
    */
@@ -1417,13 +1615,13 @@ private:
 
   bool requestObject( khtml::ChildFrame *child, const KURL &url, const KParts::URLArgs &args = KParts::URLArgs() );
 
-  DOM::EventListener *createHTMLEventListener( QString code, QString name );
+  DOM::EventListener *createHTMLEventListener( QString code, QString name, DOM::NodeImpl *node );
 
   DOM::HTMLDocumentImpl *docImpl() const;
   DOM::DocumentImpl *xmlDocImpl() const;
   khtml::ChildFrame *frame( const QObject *obj );
 
-  khtml::ChildFrame *recursiveFrameRequest( const KURL &url, const KParts::URLArgs &args, bool callParent = true );
+  khtml::ChildFrame *recursiveFrameRequest( KHTMLPart *callingHtmlPart, const KURL &url, const KParts::URLArgs &args, bool callParent = true );
 
   bool checkLinkSecurity( const KURL &linkURL,const QString &message = QString::null, const QString &button = QString::null );
   QVariant executeScript( const QString& filename, int baseLine, const DOM::Node &n, const QString& script );
@@ -1440,8 +1638,7 @@ private:
   void emitLoadEvent();
 
   bool initFindNode( bool selection, bool reverse, bool fromCursor );
-  void findText();
-  void findTextNext();
+
   void extendSelection( DOM::NodeImpl* node, long offset, DOM::Node& selectionNode, long& selectionOffset, bool right, bool paragraph );
   /** extends the current selection to the given content-coordinates @p x, @p y
    * @param x content x-coordinate
@@ -1458,6 +1655,10 @@ private:
    */
   bool isExtendingSelection() const;
   khtml::Decoder *createDecoder();
+  QString defaultEncoding() const;
+
+  /** .html, .xhtml or .xml */
+  QString defaultExtension() const;
 
   /** @internal
    * generic zoom in
@@ -1471,7 +1672,9 @@ private:
   void emitCaretPositionChanged(const DOM::Node &node, long offset);
 
   void setDebugScript( bool enable );
-  
+
+  void runAdFilter();
+
   KHTMLPartPrivate *d;
   friend class KHTMLPartPrivate;
 };
