@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef __kmimetype_h__
@@ -26,13 +26,11 @@
 #include <qstringlist.h>
 #include <qvaluelist.h>
 #include <qpixmap.h>
+
 #include <kicontheme.h>
-
 #include <kurl.h>
-#include <kdemacros.h>
-
-#include "ksycocatype.h"
-#include "kservicetype.h"
+#include <ksycocatype.h>
+#include <kservicetype.h>
 
 class KSimpleConfig;
 /**
@@ -46,7 +44,7 @@ class KSimpleConfig;
  *
  * @see KServiceType
  */
-class KMimeType : public KServiceType
+class KIO_EXPORT KMimeType : public KServiceType
 {
   K_SYCOCATYPE( KST_KMimeType, KServiceType )
 
@@ -361,16 +359,17 @@ public:
    */
   static Ptr findByFileContent( const QString &fileName, int *accuracy=0 );
 
+  struct Format{
+     bool text : 1;
+     enum { NoCompression=0, GZipCompression } compression : 4;
+     unsigned dummy : 27;
+  };
+
   /**
    * Returns whether a file has an internal format that is human readable,
    * or that would be human readable after decompression.
    * @since 3.2
    */
-  struct Format{
-     bool text : 1;
-     enum { NoCompression=0, GZipCompression } compression : 4;
-     int dummy : 27;
-  };
   static Format findFormatByFileContent( const QString &fileName );
 
   /**
@@ -475,7 +474,7 @@ protected:
  * Folder mime type. Handles locked folders, for instance.
  * @short Mimetype for a folder (inode/directory)
  */
-class KFolderType : public KMimeType
+class KIO_EXPORT KFolderType : public KMimeType
 {
   K_SYCOCATYPE( KST_KFolderType, KMimeType )
 
@@ -504,7 +503,7 @@ protected:
  * Handles mount/umount icon, and user-defined properties.
  * @short Mimetype for a .desktop file
  */
-class KDEDesktopMimeType : public KMimeType
+class KIO_EXPORT KDEDesktopMimeType : public KMimeType
 {
   K_SYCOCATYPE( KST_KDEDesktopMimeType, KMimeType )
 
@@ -562,10 +561,26 @@ public:
   static QValueList<Service> userDefinedServices( const QString& path, bool bLocalFiles );
 
   /**
-   * @param _path is the path of the desktop entry.
+   * Overload of userDefinedServices for speed purposes: it takes a KConfig* so that
+   * the caller can check things in the file without having it parsed twice.
+   * @since 3.4
+   */
+  static QValueList<Service> userDefinedServices( const QString& path, KConfig& config, bool bLocalFiles );
+
+  /**
+   * Overload of userDefinedServices but also allows you to pass a list of urls for this file.
+   * This allows for the menu to be changed depending on the exact files via
+   * the X-KDE-GetActionMenu extension.
+   * @since 3.5
+   */
+  static QValueList<Service> userDefinedServices( const QString& path, KConfig& config, bool bLocalFiles,  const KURL::List & file_list);
+
+  /**
+   * @param path is the path of the desktop entry.
+   * @param service the service to execute
    * @deprecated, see the other executeService
    */
-  static void executeService( const QString& _path, KDEDesktopMimeType::Service& _service ) KDE_DEPRECATED;
+  static void executeService( const QString& path, KDEDesktopMimeType::Service& service ) KDE_DEPRECATED;
 
   /**
    * Execute @p service on the list of @p urls.
@@ -588,8 +603,9 @@ public:
   static pid_t run( const KURL& _url, bool _is_local );
 
 protected:
-  virtual QPixmap pixmap(KIcon::Group a, int b, int c, QString *d) const
-     { return KMimeType::pixmap(a, b, c, d); }
+  virtual QPixmap pixmap( KIcon::Group group, int force_size = 0, int state = 0,
+                          QString * path = 0L ) const
+     { return KMimeType::pixmap( group, force_size, state, path ); }
 
   static pid_t runFSDevice( const KURL& _url, const KSimpleConfig &cfg );
   static pid_t runApplication( const KURL& _url, const QString & _serviceFile );
@@ -603,7 +619,7 @@ protected:
  * The mime type for executable files.
  * @short MimeType for any executable, like /bin/ls
  */
-class KExecMimeType : public KMimeType
+class KIO_EXPORT KExecMimeType : public KMimeType
 {
   K_SYCOCATYPE( KST_KExecMimeType, KMimeType )
 
